package com.songhua.web.controller.system;

import com.songhua.common.annotation.Log;
import com.songhua.common.core.controller.BaseController;
import com.songhua.common.core.domain.AjaxResult;
import com.songhua.common.core.page.TableDataInfo;
import com.songhua.common.enums.BusinessType;
import com.songhua.common.utils.poi.ExcelUtil;
import com.songhua.system.domain.ShhTicketRules;
import com.songhua.system.service.IShhTicketRulesService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 票种规则Controller
 *
 * @author ruoyi
 * @date 2024-11-04
 */
@RestController
@RequestMapping("/ticket/rules")
public class ShhTicketRulesController extends BaseController {
    @Autowired
    private IShhTicketRulesService shhTicketRulesService;

    /**
     * 查询票种规则列表
     */
    @GetMapping("/list")
    public TableDataInfo list(ShhTicketRules shhTicketRules) {
        startPage();
        List<ShhTicketRules> list = shhTicketRulesService.selectShhTicketRulesList(shhTicketRules);
        return getDataTable(list);
    }

    /**
     * 导出票种规则列表
     */
    @Log(title = "票种规则", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ShhTicketRules shhTicketRules) {
        List<ShhTicketRules> list = shhTicketRulesService.selectShhTicketRulesList(shhTicketRules);
        ExcelUtil<ShhTicketRules> util = new ExcelUtil<ShhTicketRules>(ShhTicketRules.class);
        util.exportExcel(response, list, "票种规则数据");
    }

    /**
     * 获取票种规则详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(shhTicketRulesService.selectShhTicketRulesById(id));
    }

    /**
     * 新增票种规则
     */
    @Log(title = "票种规则", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ShhTicketRules shhTicketRules) {
        return toAjax(shhTicketRulesService.insertShhTicketRules(shhTicketRules));
    }

    /**
     * 修改票种规则
     */
    @Log(title = "票种规则", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ShhTicketRules shhTicketRules) {
        return toAjax(shhTicketRulesService.updateShhTicketRules(shhTicketRules));
    }

    /**
     * 删除票种规则
     */
    @Log(title = "票种规则", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(shhTicketRulesService.deleteShhTicketRulesByIds(ids));
    }
}
