package com.songhua.system.service.impl;

import java.util.List;

import com.songhua.common.exception.ServiceException;
import com.songhua.common.utils.DateUtils;
import com.songhua.common.utils.StringUtils;
import com.songhua.system.domain.PzRawDataVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.songhua.system.mapper.PzRawDataMapper;
import com.songhua.system.domain.PzRawData;
import com.songhua.system.service.IPzRawDataService;

/**
 * 原始数据导入Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-11-04
 */
@Service
public class PzRawDataServiceImpl implements IPzRawDataService 
{
    @Autowired
    private PzRawDataMapper pzRawDataMapper;




    /**
     * 查询原始数据导入
     * 
     * @param id 原始数据导入主键
     * @return 原始数据导入
     */
    @Override
    public PzRawData selectPzRawDataById(Long id)
    {
        return pzRawDataMapper.selectPzRawDataById(id);
    }

    /**
     * 查询原始数据导入列表
     * 
     * @param pzRawData 原始数据导入
     * @return 原始数据导入
     */
    @Override
    public List<PzRawDataVo> selectPzRawDataList(PzRawData pzRawData)
    {
        return pzRawDataMapper.selectPzRawDataList(pzRawData);
    }

    /**
     * 新增原始数据导入
     * 
     * @param pzRawData 原始数据导入
     * @return 结果
     */
    @Override
    public int insertPzRawData(PzRawData pzRawData)
    {
        pzRawData.setCreateTime(DateUtils.getNowDate());
        return pzRawDataMapper.insertPzRawData(pzRawData);
    }

    @Override
    public int insertPzRawDataVo(PzRawDataVo pzRawDataVo)
    {
        pzRawDataVo.setCreateTime(DateUtils.getNowDate());
        return pzRawDataMapper.insertPzRawDataVo(pzRawDataVo);
    }

    /**
     * 修改原始数据导入
     * 
     * @param pzRawData 原始数据导入
     * @return 结果
     */
    @Override
    public int updatePzRawData(PzRawData pzRawData)
    {
        return pzRawDataMapper.updatePzRawData(pzRawData);
    }
    @Override
    public int updatePzRawDataVo(PzRawDataVo pzRawDataVo)
    {
        return pzRawDataMapper.updatePzRawDataVo(pzRawDataVo);
    }

    /**
     * 批量删除原始数据导入
     * 
     * @param ids 需要删除的原始数据导入主键
     * @return 结果
     */
    @Override
    public int deletePzRawDataByIds(Long[] ids)
    {
        return pzRawDataMapper.deletePzRawDataByIds(ids);
    }

    /**
     * 删除原始数据导入信息
     * 
     * @param id 原始数据导入主键
     * @return 结果
     */
    @Override
    public int deletePzRawDataById(Long id)
    {
        return pzRawDataMapper.deletePzRawDataById(id);
    }

    @Override
    public PzRawDataVo checkIfDataExists(String ticketName)
    {
        PzRawDataVo pzRawDataVo = pzRawDataMapper.checkIfDataExists(ticketName);
        return pzRawDataVo;
    }

    /**
     * 导入用户数据
     *
     * @param userList        用户数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName        操作用户
     * @return 结果
     */
    @Override
    public String importData(List<PzRawDataVo> userList, Boolean isUpdateSupport, String operName) {
        if (StringUtils.isNull(userList) || userList.size() == 0) {
            throw new ServiceException("导入用户数据不能为空！");
        }
        StringBuilder successMsg = new StringBuilder();
        StringBuilder failureMsg = new StringBuilder();
        for (PzRawDataVo data : userList) {
            try {
                // 检查数据是否已存在
                PzRawDataVo isExist = checkIfDataExists(data.getTicketName());
                data.setTicketId(isExist.getId());
                insertPzRawDataVo(data);
                String msg = "【成功】" + data.toString() + " 导入成功：" ;
                failureMsg.append(msg).append("\n");
            } catch (Exception e) {
                String msg = "【失败】" + data.toString() + " 导入失败：" + e.getMessage();
                failureMsg.append(msg).append("\n");
            }
        }
        return successMsg.toString();
    }


}
