package com.songhua.system.service.impl;

import com.songhua.system.domain.ShhTicketRules;
import com.songhua.system.domain.ShhTicketRulesData;
import com.songhua.system.mapper.ShhTicketRulesDataMapper;
import com.songhua.system.mapper.ShhTicketRulesMapper;
import com.songhua.system.service.IShhTicketRulesService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 票种规则Service业务层处理
 *
 * @author ruoyi
 * @date 2024-11-04
 */
@Service
public class ShhTicketRulesServiceImpl implements IShhTicketRulesService {
    @Autowired
    private ShhTicketRulesMapper shhTicketRulesMapper;
    @Autowired
    private ShhTicketRulesDataMapper shhTicketRulesDataMapper;

    /**
     * 查询票种规则
     *
     * @param id 票种规则主键
     * @return 票种规则
     */
    @Override
    public ShhTicketRules selectShhTicketRulesById(Long id) {
        ShhTicketRules returnEntity = shhTicketRulesMapper.selectShhTicketRulesById(id);
        String[] split = returnEntity.getTicketId().split(",");
        List<Long> list = Arrays.stream(split).map(Long::parseLong).collect(Collectors.toList());
        returnEntity.setTicketList(list);
        return returnEntity;
    }

    /**
     * 查询票种规则列表
     *
     * @param shhTicketRules 票种规则
     * @return 票种规则
     */
    @Override
    public List<ShhTicketRules> selectShhTicketRulesList(ShhTicketRules shhTicketRules) {
        return shhTicketRulesMapper.selectShhTicketRulesList(shhTicketRules);
    }

    /**
     * 新增票种规则
     *
     * @param shhTicketRules 票种规则
     * @return 结果
     */
    @Override
    public int insertShhTicketRules(ShhTicketRules shhTicketRules) {
        shhTicketRulesMapper.insertShhTicketRules(shhTicketRules);
        extracted(shhTicketRules);
        return 1;
    }

    private void extracted(ShhTicketRules shhTicketRules) {
        List<ShhTicketRulesData> saveList = new ArrayList<>();
        if (!CollectionUtils.isEmpty(shhTicketRules.getTicketList())) {
            for (Long var : shhTicketRules.getTicketList()) {
                ShhTicketRulesData saveData = new ShhTicketRulesData();
                saveData.setRulesId(shhTicketRules.getId());
                saveData.setTicketId(var);
                saveList.add(saveData);
            }
            if (!CollectionUtils.isEmpty(saveList)) {
                shhTicketRulesDataMapper.insertTicketRulesDataBatch(saveList);
            }
        }
    }

    /**
     * 修改票种规则
     *
     * @param shhTicketRules 票种规则
     * @return 结果
     */
    @Override
    public int updateShhTicketRules(ShhTicketRules shhTicketRules) {
        if (!CollectionUtils.isEmpty(shhTicketRules.getTicketList())) {
            shhTicketRulesDataMapper.deleteShhTicketRulesDataByRulesId(shhTicketRules.getId());
            extracted(shhTicketRules);
        }
        return shhTicketRulesMapper.updateShhTicketRules(shhTicketRules);
    }

    /**
     * 批量删除票种规则
     *
     * @param ids 需要删除的票种规则主键
     * @return 结果
     */
    @Override
    public int deleteShhTicketRulesByIds(Long[] ids) {
        for (Long id : ids) {
            shhTicketRulesDataMapper.deleteShhTicketRulesDataByRulesId(id);
        }
        return shhTicketRulesMapper.deleteShhTicketRulesByIds(ids);
    }

    /**
     * 删除票种规则信息
     *
     * @param id 票种规则主键
     * @return 结果
     */
    @Override
    public int deleteShhTicketRulesById(Long id) {
        return shhTicketRulesMapper.deleteShhTicketRulesById(id);
    }


}
